@@ -51,7 +51,7 @@
 #' * [plot.vp()]
 #' * [as.data.frame.vpts()]
 #' * \code{\link[=[.vpts]{[vpts()}}
-#'
+#' @returns For [summary.vpts()]: prints the summary of the`vpts` object.
 #' @examples
 #' # Check if an object is of class vpts
 #' is.vpts(example_vpts)
@@ -66,19 +66,19 @@ summary.vpts <- function(object, ...) {
 }
 
 #' Print summary for an object of class `vpts`
-#'
-#' @noRd
-#'
+#' @param digits The number of significant digits to use when printing. Defaults to `max(3L, getOption("digits") - 3L)`.
+#' @rdname summary.vpts
+#' @returns For [print.vpts()]: prints the summary of the `vpts` object.
 #' @export
 print.vpts <- function(x, digits = max(3L, getOption("digits") - 3L), ...) {
   stopifnot(inherits(x, "vpts"))
   if (is.null(x[["height"]])) {
-    warning(glue("`x` is a legacy `vpts` object without a column `height`. ",
+    warning(glue::glue("`x` is a legacy `vpts` object without a column `height`. ",
             "Use convert_legacy() to avoid errors."))
     x <- convert_legacy(x)
   }
   if (is.null(x[["datetime"]])) {
-    warning(glue("`x` is a legacy `vpts` object without a column `datetime`. ",
+    warning(glue::glue("`x` is a legacy `vpts` object without a column `datetime`. ",
             "Use convert_legacy() to avoid errors."))
     x <- convert_legacy(x)
   }
@@ -148,11 +148,10 @@ dim.vpts <- function(x) {
 #' @param i Integer. Index/indices specifying which range of vertical profiles
 #'   to extract.
 #'
-#' @return A `vpts` object containing a subset of vertical profiles (`vp`) or a
+#' @return For `[.vpts`: A `vpts` object containing a subset of vertical profiles (`vp`) or a
 #'   `vp` object when subsetting a single vertical profile (`vp`).
 #'
-#' @export
-#'
+#' @rdname summary.vpts
 #' @examples
 #' # The example vpts contains 1934 profiles (i.e. datetimes)
 #' dim(example_vpts)
@@ -165,6 +164,7 @@ dim.vpts <- function(x) {
 #'
 #' # Subset vpts to remove the first 10 profiles
 #' example_vpts[-1:-10] # A vpts object with 10 less profiles
+#' @export
 `[.vpts` <- function(x, i) {
   stopifnot(inherits(x, "vpts"))
 
